bayespy.inference.vmp.nodes.beta.BetaDistribution.compute_moments_and_cgf
=========================================================================

.. currentmodule:: bayespy.inference.vmp.nodes.beta

.. automethod:: BetaDistribution.compute_moments_and_cgf